﻿#!/usr/bin/env python
# -*- coding: utf-8 -*-

# ---------------------------------------------------------------------
# mythtv remote control tool for linux and windows
# ---------------------------------------------------------------------
# Copyright (c) 2008 SCS TeleMedia AG <scs@telemedia.ch>
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. The name of the author may not be used to endorse or promote products
#    derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
# AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
# THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
# --------------------------------------------------------------------------
#  $Id: mrc.py,v 1.8 2009-08-10 15:38:32 obiwan Exp $
# --------------------------------------------------------------------------
# ###########################################################
# TODO:
# NOTES:
# ###########################################################

"""
__author__  = "$Author: obiwan $ (cschnee@telemedia.ch)"
__appname__ = "mrc.py"
__version__ = "$Revision: 1.8 $"
__date__    = "$Date: 2009-08-10 15:38:32 $"
__license__ = "BSD"
"""

from PythonCard import model, dialog
import telnetlib, sys, os, socket
from PythonCard.components import textfield, statictext, button

PORT = 6546
NTIMEOUT = 2
IPCACHE_FILENAME = 'mrc_ipcache'

class mrc(model.Background):

    def on_initialize(self, event):
        # try to read ip cache
        cached_ip = self.read_ipcache()
        self.components.tfFrontendAddress.text = cached_ip
    
    def _send_cmd(self, cmd):
        fe_ip = self.components.tfFrontendAddress.text
        try:
            num_ip = socket.gethostbyname(fe_ip)
        except socket.gaierror, dnserr:
            print fe_ip, dnserr
            dialog.alertDialog(self, '%s is no valid ip address, system reported:\n\n%s' %(fe_ip, dnserr[1]), 'Hostname / IP Error!')
            return False
        try:
            tn = telnetlib.Telnet(fe_ip, PORT)
            tn.write('%s\n'%cmd)
            tn.read_until('OK',NTIMEOUT)
            self.update_ipcache(fe_ip)
            tn.close()
        except socket.error, sockerr:
            dialog.alertDialog(self, 'Connection refused or timed out, system reported:\n\n%s' %sockerr[1], 'Connection refused / timed out!')
            return False

    #################
    # GUI Events
    #################            
    def on_btnMusic_mouseClick(self, event):
        self._send_cmd('jump playmusic')

    def on_btnTV_mouseClick(self, event):
        self._send_cmd('jump livetv')
        
    def on_btnRecordings_mouseClick(self, event):
        self._send_cmd('jump playbackbox')
        
    def on_btnVolUp_mouseClick(self, event):
        self._send_cmd('key f11')

    def on_btnVolDn_mouseClick(self, event):
        self._send_cmd('key f10')
        
    def on_btnDown_mouseClick(self, event):
        self._send_cmd('key down')

    def on_btnUp_mouseClick(self, event):
        self._send_cmd('key up')

    def on_btnLeft_mouseClick(self, event):
        self._send_cmd('key left')

    def on_btnRight_mouseClick(self, event):
        self._send_cmd('key right')
     
    def on_btnOK_mouseClick(self, event):
        self._send_cmd('key enter')

    def on_btnEsc_mouseClick(self, event):
        self._send_cmd('key escape')
     
    def on_btnMenu_mouseClick(self, event):
        self._send_cmd('key m')

    def on_btnPause_mouseClick(self, event):
        self._send_cmd('key p')
        
    def on_btnMute_mouseClick(self, event):
        self._send_cmd('key f9')
        
    def on_btnNews_mouseClick(self, event):
        self._send_cmd('jump mythnews')
        
    def on_btnWeather_mouseClick(self, event):
        self._send_cmd('jump mythweather')
        
    def on_btnImages_mouseClick(self, event):
        self._send_cmd('jump mythgallery')
        
    def on_btnVideo_mouseClick(self, event):
        self._send_cmd('jump mythvideo')
        
    def on_btnFForward_mouseClick(self, event):
        self._send_cmd('play seek forward')
        
    def on_btnFRewind_mouseClick(self, event):
        self._send_cmd('play seek backward')

    def on_btnSkipF_mouseClick(self, event):
        self._send_cmd('key pageup')

    def on_btnSkipR_mouseClick(self, event):
        self._send_cmd('key pagedown')
    
    def on_btnExit_mouseClick(self, event):
        print 'Exit!'
        sys.exit(0)
        
    #################
    # Functions
    #################  
    def update_ipcache(self, ip):
        ipcf = open(IPCACHE_FILENAME, 'w')
        ipcf.write(ip)
        ipcf.close()
        
    def read_ipcache(self):
        try:
            ipcf = open(IPCACHE_FILENAME, 'r')
            ip = ipcf.read(256)
        except:
            ip = '0.0.0.0'
            
        return ip
        
#################
# MAIN namespace / Main Loop
#################
if __name__ == '__main__':
	app = model.Application(mrc)
	app.MainLoop()
